changeset 12283:decfedf9138d v8.0.1021

patch 8.0.1021: older Gnome terminal still echoes t_RC commit https://github.com/vim/vim/commit/dc5471d482c372f547006325d7c8f16d6cc9d371 Author: Bram Moolenaar <Bram@vim.org> Date: Wed Aug 30 18:59:03 2017 +0200 patch 8.0.1021: older Gnome terminal still echoes t_RC Problem: Older Gnome terminal still echoes t_RC. (Fracois Ingelrest) Solution: Check for version > 3000 instead of 4000.
author Christian Brabandt <cb@256bit.org>
date Wed, 30 Aug 2017 19:00:06 +0200
parents e10600614c14
children 85ca00d2ffa7
files src/term.c src/version.c
diffstat 2 files changed, 6 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -770,6 +770,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    1021,
+/**/
     1020,
 /**/
     1019,
--- a/src/term.c
+++ b/src/term.c
@@ -4562,9 +4562,10 @@ check_termcode(
 				&& STRNCMP(tp + extra - 2, "1;95;0c", 7) == 0)
 			    is_not_xterm = TRUE;
 #  endif
-			/* Gnome Terminal.app sends 1;4402;0, assuming any
-			 * version number over 4000 is not an xterm. */
-			if (col >= 4000)
+			/* Gnome Terminal.app sends 1;3801;0 or 1;4402;0,
+			 * assuming any version number over 3000 is not an
+			 * xterm. */
+			if (col >= 3000)
 			    is_not_xterm = TRUE;
 
 			/* Only request the cursor style if t_SH and t_RS are